OnExpressionColumnSqL class

Constructors

OnExpressionColumnSqL({required String originAlias, required ColumnSql column, required String operation, required dynamic value})

Properties

column ColumnSql
final
hashCode int
The hash code for this object.
no setterinherited
operation String
final
originAlias String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited